# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-05 08:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0037_auto_20191202_1930'),
    ]

    operations = [
        migrations.AddField(
            model_name='campaignrecord',
            name='share_qrcode',
            field=models.ImageField(blank=True, null=True, upload_to=b'bee_django_crm/campaign_record/share_qrcode', verbose_name=b'\xe5\xb0\x8f\xe7\xa8\x8b\xe5\xba\x8f\xe4\xba\x8c\xe7\xbb\xb4\xe7\xa0\x81'),
        ),
        migrations.AlterField(
            model_name='campaignrecord',
            name='status',
            field=models.IntegerField(choices=[(1, b'\xe8\xbf\x9b\xe8\xa1\x8c\xe4\xb8\xad'), (2, b'\xe5\xb7\xb2\xe6\x8f\x90\xe5\x8f\x96'), (3, b'\xe5\xb7\xb2\xe6\xb6\x88\xe8\xb4\xb9')], default=1),
        ),
    ]
