# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-02 07:12
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0035_auto_20191128_1829'),
    ]

    operations = [
        migrations.AddField(
            model_name='wxuser',
            name='avatar_url',
            field=models.URLField(null=True, verbose_name=b'\xe5\xa4\xb4\xe5\x83\x8f\xe9\x93\xbe\xe6\x8e\xa5'),
        ),
    ]
