{% extends "bee_django_crm/base.html" %}
{% load bootstrap3 %}
{% load static %}
{% block content %}
    {% include 'bee_django_crm/logo.html' %}
    {% include 'bee_django_crm/nav.html' %}
    <div style="margin: 20px;">
        <form method="post">
            {% csrf_token %}
            {% bootstrap_form form %}
            {% bootstrap_button '提交' %}
{#            {{ form.as_ul }}#}
            {#            {{ preuser_form.as_ul }}#}

{#            <input type="submit" value="提交"/>#}
        </form>
    </div>
{% endblock %}


{% block scripts %}
    <script>
        $(document).ready(function () {
            //时间
            $.datetimepicker.setLocale('ch');
            var $birthday = $("#id_birthday");
            $birthday.datetimepicker({
                format: 'Y-m-d',
                timepicker: false,
                scrollMonth: false,
                scrollTime: false,
                scrollInput: false
            });
            {#            $("#id_source").prepend("<option value='{{ source.id }}'  selected = 'selected'>当前：{{ source.name }}</option>");   //为Select插入一个Option(第一个位置)#}

        });
        $('#id_referral_user1').select2(
            {
                placeholder: '输入姓名筛选',
                allowClear: true
            }
        );
        $('#id_referral_user2').select2(
            {
                placeholder: '输入姓名筛选',
                allowClear: true
            }
        );

    </script>
{% endblock %}