# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-12 06:36
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0041_auto_20191210_1346'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='campaignrecord',
            options={'ordering': ['-created_at']},
        ),
        migrations.RemoveField(
            model_name='wxuser',
            name='source_mkuser_id',
        ),
        migrations.AlterField(
            model_name='campaignrecord',
            name='status',
            field=models.IntegerField(choices=[(1, b'\xe8\xbf\x9b\xe8\xa1\x8c\xe4\xb8\xad'), (2, b'\xe5\xb7\xb2\xe5\xae\x8c\xe6\x88\x90'), (3, b'\xe5\xb7\xb2\xe6\xb6\x88\xe8\xb4\xb9')], default=1),
        ),
        migrations.AlterField(
            model_name='wxuser',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name=b'\xe6\x9d\xa5\xe6\xba\x90\xe7\xbc\xa6\xe5\xae\xa2id'),
        ),
    ]
