{% extends "bee_django_crm/base.html" %}
{% load bootstrap3 %}
{% load static %}
{% block content %}
    {% include 'bee_django_crm/logo.html' %}
    {% include 'bee_django_crm/nav.html' %}
    <h4>协议内容</h4>
    <div style="margin: 5px 0;">
        <form method="post">
            {% csrf_token %}
            {% bootstrap_form form %}
            {% bootstrap_button '提交' %}
        </form>
    </div>
{% endblock %}


{% block scripts %}

{% endblock %}