# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-06 09:05
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_crm', '0039_wxuser_source_mkuser_id'),
    ]

    operations = [
        migrations.AddField(
            model_name='campaignrecord',
            name='bind_preuser',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bee_django_crm.PreUser', verbose_name=b'\xe7\xba\xa2\xe5\x8c\x85\xe5\x8f\x91\xe6\x94\xbe\xe6\x96\xb0peruser\xe8\xb4\xa6\xe5\x8f\xb7'),
        ),
        migrations.AddField(
            model_name='campaignrecord',
            name='bind_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name=b'\xe7\xba\xa2\xe5\x8c\x85\xe5\x8f\x91\xe6\x94\xbe\xe7\x94\xa8\xe6\x88\xb7\xe8\xb4\xa6\xe5\x8f\xb7'),
        ),
        migrations.AddField(
            model_name='campaignrecord',
            name='is_mk',
            field=models.BooleanField(default=False, verbose_name=b'\xe6\x98\xaf\xe5\x90\xa6\xe6\x98\xaf\xe8\x80\x81\xe7\xbc\xa6\xe5\xae\xa2'),
        ),
        migrations.AddField(
            model_name='wxuser',
            name='city',
            field=models.CharField(blank=True, max_length=20, null=True, verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1\xe5\x9f\x8e\xe5\xb8\x82'),
        ),
        migrations.AddField(
            model_name='wxuser',
            name='country',
            field=models.CharField(blank=True, max_length=20, null=True, verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1\xe5\x9b\xbd\xe5\xae\xb6'),
        ),
        migrations.AddField(
            model_name='wxuser',
            name='gender',
            field=models.IntegerField(blank=True, choices=[(1, b'\xe7\x94\xb7'), (2, b'\xe5\xa5\xb3')], null=True, verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1\xe6\x80\xa7\xe5\x88\xab'),
        ),
        migrations.AddField(
            model_name='wxuser',
            name='province',
            field=models.CharField(blank=True, max_length=20, null=True, verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1\xe7\x9c\x81\xe4\xbb\xbd'),
        ),
        migrations.AddField(
            model_name='wxuser',
            name='tel',
            field=models.CharField(blank=True, max_length=20, null=True, verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1\xe7\x94\xb5\xe8\xaf\x9d'),
        ),
    ]
