# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-02 11:30
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0036_wxuser_avatar_url'),
    ]

    operations = [
        migrations.AddField(
            model_name='bargainrecord',
            name='wx_avatar_url',
            field=models.URLField(null=True, verbose_name=b'\xe5\xa4\xb4\xe5\x83\x8f\xe9\x93\xbe\xe6\x8e\xa5'),
        ),
        migrations.AddField(
            model_name='bargainrecord',
            name='wx_nickname',
            field=models.CharField(max_length=180, null=True, verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1\xe6\x98\xb5\xe7\xa7\xb0'),
        ),
        migrations.AlterField(
            model_name='wxuser',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
    ]
