# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-28 05:12
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0032_auto_20191127_1721'),
    ]

    operations = [
        migrations.CreateModel(
            name='BargainRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('result', models.FloatField(verbose_name=b'\xe7\xa0\x8d\xe4\xbb\xb7\xe7\xbb\x93\xe6\x9e\x9c')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
            ],
            options={
                'db_table': 'bee_django_crm_bargain_record',
            },
        ),
        migrations.CreateModel(
            name='BargainReward',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=180, verbose_name=b'\xe5\xa5\x96\xe5\x8a\xb1\xe5\x90\x8d\xe7\xa7\xb0')),
            ],
            options={
                'db_table': 'bee_django_bargain_reward',
            },
        ),
        migrations.CreateModel(
            name='CampaignRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('count', models.IntegerField(verbose_name=b'\xe7\xa0\x8d\xe4\xbb\xb7\xe6\xac\xa1\xe6\x95\xb0')),
                ('result', models.FloatField(verbose_name=b'\xe7\xa0\x8d\xe4\xbb\xb7\xe7\xbb\x93\xe6\x9e\x9c')),
                ('status', models.IntegerField(choices=[(1, b'\xe8\xbf\x9b\xe8\xa1\x8c\xe4\xb8\xad'), (2, b'\xe5\xb7\xb2\xe6\x8f\x90\xe5\x8f\x96')], default=1)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('reward', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_crm.BargainReward', verbose_name=b'\xe5\xa5\x96\xe5\x93\x81')),
                ('wxuser', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_crm.WXUser', verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1\xe7\x94\xa8\xe6\x88\xb7')),
            ],
            options={
                'db_table': 'bee_django_crm_bargain_campaign_record',
            },
        ),
        migrations.AddField(
            model_name='bargainrecord',
            name='campaign_record',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_crm.CampaignRecord', verbose_name=b'\xe5\x8f\x82\xe4\xb8\x8e\xe8\xae\xb0\xe5\xbd\x95'),
        ),
        migrations.AddField(
            model_name='bargainrecord',
            name='op_wxuser',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='op_wxuser', to='bee_django_crm.WXUser', verbose_name=b'\xe5\x8a\xa9\xe5\x8a\x9b\xe7\x9a\x84\xe5\xbe\xae\xe4\xbf\xa1\xe7\x94\xa8\xe6\x88\xb7'),
        ),
    ]
