# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-27 09:15
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_crm', '0030_auto_20191122_1324'),
    ]

    operations = [
        migrations.CreateModel(
            name='WXUser',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('nickname', models.CharField(max_length=180, verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1\xe6\x98\xb5\xe7\xa7\xb0')),
                ('open_id', models.CharField(max_length=180, verbose_name=b'\xe5\xbe\xae\xe4\xbf\xa1openid')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'bee_django_crm_wx_user',
            },
        ),
    ]
