<div style="margin-top: 30px;">
    <h4>缦学堂新年红包礼</h4>
</div>
<div>
    <p>谢谢您与缦学堂度过了第三个年头</p>
    <p>
        新的一年即将到来</p>
    <p>
        即日起至2019.12.31</p>
    <p>
        邀请您与亲友分享缦学堂的小程序</p>
    <p>
        一起拿红包</p>
    <p>
        让我们将习琴的喜悦传递出去</p>
    <p>
        让更多人知道有一种生活和美好</p>
    <p>
        叫做缦学堂</p>
    <p>
</div>

<div style="margin-top: 30px;">
    <h4>红包礼规则说明：</h4>
</div>
<div>
    <p>1. 红包分享时间：即日起至2019.12.31止</p>
    <p>
        2. 长按下方小程序的二维码，保存图片，用微信扫描打开。</p>
    <p>
        3. 开启活动后，转发小程序或分享到朋友圈，邀请亲友帮忙抢红包。</p>
    <p>
        4. 每人仅可帮助3位亲友抢红包。</p>
    <p>
        5. 每人在亲友帮助下，最高可累计获得缦学堂1000元红包。</p>
    <p>
        6. 获得红包后，可绑定到对应账号，一经绑定不可更改，绑定后可继续拆红包</p>
    <p>
        7. 缦客红包可于“核心课”、“终身缦客”、“赵铠亲斫琴”、“王可逊断纹琴”、“王可逊断纹蕉叶琴”、“练习琴”使用。</p>
    <p>
        8. 非缦客红包可报名“入门课”使用。</p>
    <p>
        9. 红包金额使用时间：2020.01.01-12.31</p>
    <p>
        10. 红包一经使用，不可继续拆红包</p>
    <p>
        11. 如有疑问，请洽询您的专属客服。非缦客请洽前端客服青青 电话：135 2266 5001</p>
    <p>
</div>