# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-13 09:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0042_auto_20191212_1436'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='campaignrecord',
            options={'ordering': ['-created_at'], 'permissions': (('view_campaign_record_list', 'view_campaign_record_list'), ('view_campaign_record_detail', 'view_campaign_record_detail'))},
        ),
        migrations.AddField(
            model_name='campaignrecord',
            name='history',
            field=models.TextField(blank=True, null=True, verbose_name=b'\xe5\x8e\x86\xe5\x8f\xb2\xe8\xae\xb0\xe5\xbd\x95'),
        ),
    ]
