# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-10 05:46
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0040_auto_20191206_1705'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='bargainrecord',
            unique_together=set([('campaign_record', 'op_wxuser')]),
        ),
        migrations.AlterUniqueTogether(
            name='campaignrecord',
            unique_together=set([('wxuser', 'reward')]),
        ),
    ]
