# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-28 06:11
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0033_auto_20191128_1312'),
    ]

    operations = [
        migrations.AlterField(
            model_name='campaignrecord',
            name='count',
            field=models.IntegerField(default=0, verbose_name=b'\xe7\xa0\x8d\xe4\xbb\xb7\xe6\xac\xa1\xe6\x95\xb0'),
        ),
        migrations.AlterField(
            model_name='campaignrecord',
            name='result',
            field=models.FloatField(default=0, verbose_name=b'\xe7\xa0\x8d\xe4\xbb\xb7\xe7\xbb\x93\xe6\x9e\x9c'),
        ),
    ]
