# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-22 05:24
from __future__ import unicode_literals

import bee_django_richtext.custom_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0029_auto_20190923_1715'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contract',
            name='agreement',
            field=bee_django_richtext.custom_fields.RichTextField(app_name=b'bee_django_crm', emotion=False, image_max_size=2, img=False, model_name=b'Contract', null=True, text_min_length=5, undo_redo=False, verbose_name=b'\xe9\xa1\xbb\xe7\x9f\xa5'),
        ),
    ]
