# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-06 08:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0038_auto_20191205_1635'),
    ]

    operations = [
        migrations.AddField(
            model_name='wxuser',
            name='source_mkuser_id',
            field=models.IntegerField(null=True, verbose_name=b'\xe6\x9d\xa5\xe6\xba\x90\xe7\xbc\xa6\xe5\xae\xa2id'),
        ),
    ]
