# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-20 09:54
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0043_auto_20191213_1700'),
    ]

    operations = [
        migrations.AlterField(
            model_name='campaignrecord',
            name='is_mk',
            field=models.NullBooleanField(verbose_name=b'\xe6\x98\xaf\xe5\x90\xa6\xe6\x98\xaf\xe8\x80\x81\xe7\xbc\xa6\xe5\xae\xa2'),
        ),
    ]
