# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-28 10:29
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0034_auto_20191128_1411'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='bargainrecord',
            options={'ordering': ['-created_at']},
        ),
    ]
