# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-25 09:36
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0045_auto_20191220_1903'),
    ]

    operations = [
        migrations.AlterField(
            model_name='campaignrecord',
            name='share_qrcode',
            field=models.ImageField(blank=True, null=True, upload_to=b'bee_django_crm/gift/campaign_record/share_qrcode', verbose_name=b'\xe5\xb0\x8f\xe7\xa8\x8b\xe5\xba\x8f\xe4\xba\x8c\xe7\xbb\xb4\xe7\xa0\x81'),
        ),
    ]
